/*	$Id: find.c,v 1.1 2012/03/28 15:03:33 kristaps Exp $ */
/*
 * Copyright (c) 2012 Kristaps Dzonsons <kristaps@bsd.lv>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#include <sys/param.h>

#include <getopt.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "extern.h"

int
main(int argc, char *argv[])
{
	struct icetools	*s;
	char		 buf[MAXPATHLEN];
	size_t		 i, j, k, sz, gidsz, ressz;
	int		 ch, verbose;
	size_t		*gids;
	char		*srv, *cp;
	const char	*ep;
	extern char	*optarg;
	extern int	 optind;

	srv = NULL;
	verbose = 0;

	while (-1 != (ch = getopt(argc, argv, "s:v")))
		switch (ch) {
		case ('s'):
			srv = optarg;
			break;
		case ('v'):
			verbose = 1;
			break;
		default:
			break;
		}

	argc -= optind;
	argv += optind;

	if (NULL == (s = icetools_get(srv, verbose)))
		return(EXIT_FAILURE);

	gids = malloc(argc * sizeof(size_t));
	gidsz = 0;
	for (i = 0; i < (size_t)argc; i++) {
		for (j = 0; j < s->gsz; j++) {
			if (strcasecmp(argv[i], s->g[j]))
				continue;
			gids[gidsz] = j;
			break;
		}
		if (j == s->gsz) {
			fprintf(stderr, "%s: Bad genre\n", argv[i]);
			continue;
		}
		gidsz++;
	}

	for (ressz = i = 0; i < s->ssz; i++) {
		for (k = 0; k < gidsz; k++) {
			for (j = 0; j < s->s[i].gidsz; j++)
				if (s->s[i].gids[j] == gids[k])
					break;
			if (j < s->s[i].gidsz)
				break;
		}
		if (gidsz && k == gidsz)
			continue;
		printf("%6zu  %s\n", i + 1, s->s[i].name);
		ressz++;
	}

	free(gids);

	if (0 == ressz) {
		puts("No results found.");
		icetools_free(s);
		return(EXIT_FAILURE);
	}

	printf("Choose a stream: ");
	fflush(stdout);

	i = 0;
	if (NULL != (cp = fgetln(stdin, &sz)) && '\n' == cp[sz - 1]) {
		cp[--sz] = '\0';
		i = strtonum(cp, 1, s->ssz, &ep);
		if (NULL != ep || 0 == s->s[i - 1].urlsz)
			i = 0;
	}

	if (i > 0) {
		for (j = 0; j < s->s[i - 1].urlsz; j++) {
			snprintf(buf, sizeof(buf),
				"xmms %s %s", j ? "-e" : "",
				s->s[i - 1].urls[j]);
			system(buf);
		}
	}

	icetools_free(s);
	return(EXIT_SUCCESS);
}
