/*	$Id: ls.c,v 1.5 2012/03/28 15:03:33 kristaps Exp $ */
/*
 * Copyright (c) 2012 Kristaps Dzonsons <kristaps@bsd.lv>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#include <getopt.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include "extern.h"

static	int	 cmp(const void *, const void *);
static	void	 usage(void);

int
main(int argc, char *argv[])
{
	struct icetools	*s;
	size_t		 i;
	int		 ch, verbose, single, list;
	FILE		*f;
	char		*srv;
	extern char	*optarg;
	extern int	 optind;

	srv = NULL;
	verbose = single = list = 0;
	single = 0 == isatty(STDOUT_FILENO);

	while (-1 != (ch = getopt(argc, argv, "1ls:v")))
		switch (ch) {
		case ('1'):
			single = 1;
			break;
		case ('l'):
			list = single = 1;
			break;
		case ('s'):
			srv = optarg;
			break;
		case ('v'):
			verbose = 1;
			break;
		default:
			usage();
			return(EXIT_FAILURE);
		}

	argc -= optind;
	argv += optind;

	if (NULL == (s = icetools_get(srv, verbose)))
		return(EXIT_FAILURE);

	if (list) 
		printf("total %zu\n", s->gsz);

	f = stdout;
	if ( ! single && NULL == (f = popen("column", "w"))) {
		perror("column");
		icetools_free(s);
		return(EXIT_FAILURE);
	}

	qsort(s->g, s->gsz, sizeof(char *), cmp);

	for (i = 0; i < s->gsz; i++) {
		if (list)
			fprintf(f, "%6zu ", s->gcount[i]);
		fprintf(f, "%s\n", s->g[i]);
	}

	pclose(f);
	icetools_free(s);
	return(EXIT_SUCCESS);
}

static int
cmp(const void *p1, const void *p2) 
{

	return(strcasecmp(*(const char **)p1, *(const char **)p2));
}

static void
usage(void)
{
	extern char	*__progname;

	fprintf(stderr, "usage: %s [-1lv] [-s server]\n", __progname);
}
